==> lhcsmapi-1.1.15.tar.gz: lhcsmapi-1.1.15/lhcsmapi/dbsignal/SignalProcessing.py <==
import scipy.signal as spsig
import pandas as pd
import numpy as np

class SignalProcessing:
    """SignalProcessing class contains static methods for signal processing"""

    def first(x):
            return x.iloc[0]
    def last(x):
            return x.iloc[-1]
    
    __nameToFunction = {"first": first, "last": last, "max": max, "min": min, "median": np.median, "std": np.std, "mean": np.mean}

    @staticmethod
    def getFeatureDataframe(df, functionNamesToApply):
        """Method returns a dataFrame according to the input list of features based on the passed DataFrame object"""
        
        functionsToApply = [SignalProcessing.__nameToFunction[x] for x in functionNamesToApply]
        
        if isinstance(df, pd.DataFrame) and not df.empty:
            return df.aggregate(functionsToApply)
        else:
            return df
    
    @staticmethod
    def convertFeatureDataframeIntoRow(df, timestamp):
        """Method converts a feature dataframe as a set of rows and columns into a single row"""
        
        df1 = df.stack().swaplevel()
        df1.index=df1.index.map('{0[0]}_{0[1]}'.format) 
        
        df2 = df1.to_frame().T
        values = df2.values[0]
        columns = df2.columns
        
        df = pd.DataFrame(columns=columns)
        df.loc[0] = values
        df.index = [timestamp]
        df.index.name = 'timestamp'
        return df

    @staticmethod
    def findValueWithTimeClosestToIndexThreshold(series, indexThreshold):
        if isinstance(series, (pd.Series, pd.DataFrame)):
            array = series.index
            idx = (np.abs(array - indexThreshold)).argmin()
            return series.iloc[idx]
        else:
            raise ValueError("First argument has to be an object of Series or DataFrame!")

    @staticmethod
    def filterSignalNames(dataFrame, filterNames, kernelSize=3):
        """Method filters all columns in the passed DataFrame correlating with the names described in filterNames. It does this by applying scipy.signal's medfilt method to these columns"""
        if isinstance(dataFrame, pd.DataFrame) and not dataFrame.empty:
            for nameToFilter in filterNames:
                dataFrame[nameToFilter] = spsig.medfilt(dataFrame[nameToFilter], kernelSize)

    @staticmethod
    def calculateTimeDerivativeOfSignals(dataFrame, timeFrame, sourceSignalNames, derivativeSignalNames, kernelSize=51):
        """Method calculate time derivatives for resistance values contained in the passed DataFrame object"""
        if isinstance(dataFrame, pd.DataFrame) and not dataFrame.empty:
            for sourceName, derivativeName in zip(sourceSignalNames, derivativeSignalNames):
                SignalProcessing.__calculateTimeDerivativeOfSignal(dataFrame, timeFrame, sourceName, derivativeName, kernelSize)

    @staticmethod
    def __calculateTimeDerivativeOfSignal(dataFrame, timeFrame, sourceSignal, derivativeName, kernelSize=51):
        """Method calculate time derivative for a single Signal"""
        dataFrame[derivativeName] = spsig.medfilt(np.gradient(dataFrame[sourceSignal]) / np.gradient(timeFrame),
                                                  kernelSize)

==> lhcsmapi-1.1.123.tar.gz: lhcsmapi-1.1.123/lhcsmapi/dbsignal/SignalProcessing.py <==
import scipy.signal as spsig
import pandas as pd
import numpy as np

class SignalProcessing:
    """SignalProcessing class contains static methods for signal processing"""

    def first(x):
            return x.iloc[0]
    def last(x):
            return x.iloc[-1]
    
    __nameToFunction = {"first": first, "last": last, "max": max, "min": min, "median": np.median, "std": np.std, "mean": np.mean}

    @staticmethod
    def getFeatureDataframe(df, functionNamesToApply):
        """Method returns a dataFrame according to the input list of features based on the passed DataFrame object"""
        
        functionsToApply = [SignalProcessing.__nameToFunction[x] for x in functionNamesToApply]
        
        if isinstance(df, pd.DataFrame) and not df.empty:
            return df.aggregate(functionsToApply)
        else:
            return df
    
    @staticmethod
    def convertFeatureDataframeIntoRow(df, timestamp):
        """Method converts a feature dataframe as a set of rows and columns into a single row"""
        
        df1 = df.stack().swaplevel()
        df1.index=df1.index.map('{0[0]}_{0[1]}'.format) 
        
        df2 = df1.to_frame().T
        values = df2.values[0]
        columns = df2.columns
        
        df = pd.DataFrame(columns=columns)
        df.loc[0] = values
        df.index = [timestamp]
        df.index.name = 'timestamp'
        return df

    @staticmethod
    def findValueWithTimeClosestToIndexThreshold(series, indexThreshold):
        if isinstance(series, (pd.Series, pd.DataFrame)):
            array = series.index
            idx = (np.abs(array - indexThreshold)).argmin()
            return series.iloc[idx]
        else:
            raise ValueError("First argument has to be an object of Series or DataFrame!")

    @staticmethod
    def filterSignalNames(dataFrame, filterNames, kernelSize=3):
        """Method filters all columns in the passed DataFrame correlating with the names described in filterNames. It does this by applying scipy.signal's medfilt method to these columns"""
        if isinstance(dataFrame, pd.DataFrame) and not dataFrame.empty:
            for nameToFilter in filterNames:
                pd.options.mode.chained_assignment = None
                dataFrame[nameToFilter] = spsig.medfilt(dataFrame[nameToFilter].to_numpy(), kernelSize)
                pd.options.mode.chained_assignment = "warn"
        return dataFrame

    @staticmethod
    def calculateTimeDerivativeOfSignals(dataFrame, timeFrame, sourceSignalNames, derivativeSignalNames, kernelSize=51):
        """Method calculate time derivatives for resistance values contained in the passed DataFrame object"""
        if isinstance(dataFrame, pd.DataFrame) and not dataFrame.empty:
            for sourceName, derivativeName in zip(sourceSignalNames, derivativeSignalNames):
                SignalProcessing.__calculateTimeDerivativeOfSignal(dataFrame, timeFrame, sourceName, derivativeName, kernelSize)

    @staticmethod
    def __calculateTimeDerivativeOfSignal(dataFrame, timeFrame, sourceSignal, derivativeName, kernelSize=51):
        """Method calculate time derivative for a single Signal"""
        dataFrame[derivativeName] = spsig.medfilt(np.gradient(dataFrame[sourceSignal]) / np.gradient(timeFrame),
                                                  kernelSize)
